@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -19,15 +19,20 @@ from typing import Dict, Type
 from .base import AutoMlTransport
 from .grpc import AutoMlGrpcTransport
 from .grpc_asyncio import AutoMlGrpcAsyncIOTransport
+from .rest import AutoMlRestTransport
+from .rest import AutoMlRestInterceptor
 
 
 # Compile a registry of transports.
 _transport_registry = OrderedDict()  # type: Dict[str, Type[AutoMlTransport]]
 _transport_registry["grpc"] = AutoMlGrpcTransport
 _transport_registry["grpc_asyncio"] = AutoMlGrpcAsyncIOTransport
+_transport_registry["rest"] = AutoMlRestTransport
 
 __all__ = (
     "AutoMlTransport",
     "AutoMlGrpcTransport",
     "AutoMlGrpcAsyncIOTransport",
+    "AutoMlRestTransport",
+    "AutoMlRestInterceptor",
 )
