@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -19,15 +19,20 @@ from typing import Dict, Type
 from .base import PredictionServiceTransport
 from .grpc import PredictionServiceGrpcTransport
 from .grpc_asyncio import PredictionServiceGrpcAsyncIOTransport
+from .rest import PredictionServiceRestTransport
+from .rest import PredictionServiceRestInterceptor
 
 
 # Compile a registry of transports.
 _transport_registry = OrderedDict()  # type: Dict[str, Type[PredictionServiceTransport]]
 _transport_registry["grpc"] = PredictionServiceGrpcTransport
 _transport_registry["grpc_asyncio"] = PredictionServiceGrpcAsyncIOTransport
+_transport_registry["rest"] = PredictionServiceRestTransport
 
 __all__ = (
     "PredictionServiceTransport",
     "PredictionServiceGrpcTransport",
     "PredictionServiceGrpcAsyncIOTransport",
+    "PredictionServiceRestTransport",
+    "PredictionServiceRestInterceptor",
 )
