@@ -56,6 +56,7 @@ from google.cloud.automl_v1beta1.types import prediction_service
 from .transports.base import PredictionServiceTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc import PredictionServiceGrpcTransport
 from .transports.grpc_asyncio import PredictionServiceGrpcAsyncIOTransport
+from .transports.rest import PredictionServiceRestTransport
 
 
 class PredictionServiceClientMeta(type):
@@ -71,6 +72,7 @@ class PredictionServiceClientMeta(type):
     )  # type: Dict[str, Type[PredictionServiceTransport]]
     _transport_registry["grpc"] = PredictionServiceGrpcTransport
     _transport_registry["grpc_asyncio"] = PredictionServiceGrpcAsyncIOTransport
+    _transport_registry["rest"] = PredictionServiceRestTransport
 
     def get_transport_class(
         cls,
